@@ -37,20 +37,22 @@
 
 ; HEEx tags and slots are highlighted as HTML
 [
- (tag_name) 
- (slot_name) 
+  (tag_name)
+  (slot_name)
 ] @tag
 
 ; HEEx attributes are highlighted as HTML attributes
 (attribute_name) @tag.attribute
+
 [
   (attribute_value)
   (quoted_attribute_value)
 ] @string
 
 ; HEEx components are highlighted as modules and function calls
-(component_name [
-  (module) @type
-  (function) @function
-  "." @punctuation.delimiter
-])
+(component_name
+  [
+    (module) @type
+    (function) @function
+    "." @punctuation.delimiter
+  ])
